clear all
set more off
global path="C:/Downloads/" // Set the path to the folder with the replication files

****************************************************************************************************
** Load the city-level data and define global macro
****************************************************************************************************

use "$path/socialmedia_data_main.dta", clear
global SPcohorts="logspbsu2 logspbsu1 logspbsu3"
global SPcohortsnoDurov="logspbsu1 logspbsu3"
#d ;
global control_pop="pop pop_2 pop_3 pop_4 pop_5 " ;
global control0="" ;
global control1="$control_pop" ;
global control2="$control_pop  ac " ;
global control3="$control2 disttopiter disttomoscow city2 logwage11 lA20_24_y2010 lA25_29_y2010 
		lA30_34_y2010 lA35_39_y2010  lA40_44_y2010 lA45_49_y2010 lA50_more_y2010 he2010_A20_24 
		he2010_A25_29 he2010_A30_34 he2010_A35_39 he2010_A40_44 he2010_A45_49 he2010_A50_more" ;
global control4="$control3 University_exists ip_2011 logok2014 ef2010  educ2002" ;
global control4noOK="$control3 University_exists educ2002 ip_2011 ef2010" ;
global controlnopop4 = "ac disttopiter disttomoscow city2 logwage11 *_y2010 he2010_A20_24 he2010_A25_29 
	he2010_A30_34 he2010_A35_39 he2010_A40_44 he2010_A45_49 he2010_A50_more University_exists educ2002 
	ip_2011 logok2014 ef2010" ;
#d cr
// List controls for elections from different years as control5-control7
local controlall=""
forval i=5/7 {
	local y=95+(`i'-5)*4
	local y=`y'-int(`y'/100)*100
	local t="0`y'"
	local t=regexr("`t'","09","9")
	global control`i'="$control4 yabloko_`t' communists_`t' statusquo_`t' ldpr_`t' turnout_`t'"
	global controlnopop`i'="$controlnopop4 yabloko_`t' communists_`t' statusquo_`t' ldpr_`t' turnout_`t'"
	global control`i'noOK="$control4noOK yabloko_`t' communists_`t' statusquo_`t' ldpr_`t' turnout_`t'"
	global controlres`i'="$controlres4 yabloko_`t' communists_`t' statusquo_`t' ldpr_`t' turnout_`t'"
	local controlall="`controlall' yabloko_`t' communists_`t' statusquo_`t' ldpr_`t' turnout_`t'"
}
global control8="$control4 `controlall'"
global threshold="5"
global err=" cluster(okato_reg)"
global regtype="xi: reg"
global ivregtype="xi: ivreg2"
global proc=""
global weights = "[aweight=logpop]"
global logprot="log"
global logoldprot="logoldprot"
global loglabprot="log_Robertson_Total"
global dumprot="dum"
global dumoldprot="dumoldprot"
global dumlabprot="dum_Robertson_Total"
cd "$path/Figures" // Set the directory for storing figures

****************************************************************************************************
** Figure A2. Map of Protests across Russian Territory, Dec 10-11, 2011
****************************************************************************************************

preserve
tempfile municip
shp2dta using "$path/RUS_adm/RUS_adm1.shp", database(`municip') coordinates(municipxy) genid(id_geography) replace
use `municip'
save municip.dta, replace

use "$path/socialmedia_data_main.dta", clear
drop if dumprot==0
keep logprot n_ave dumprot lat* lon* OKATO city_name_eng
replace lon_degree = 103 if city_name_eng=="Angarsk"
replace lon_degree = 127 if city_name_eng=="Blagoveshhensk"
replace lon_degree = 101 if city_name_eng=="Bratsk"
replace lon_degree = 131 if city_name_eng=="Vladivostok"
replace lon_degree = 104 if city_name_eng=="Irkutsk"
replace lon_degree = 137 if city_name_eng=="Komsomol'sk-na-Amure"
replace lon_degree = 107 if city_name_eng=="Ulan-Ude"
replace lon_degree = 135 if city_name_eng=="Habarovsk"
replace lon_degree = 113 if city_name_eng=="Chita"
replace lon_degree = 142 if city_name_eng=="Juzhno-Sahalinsk"s
replace lon_minutes = 70 if city_name_eng=="Sochi"
replace lat_minutes = 70 if city_name_eng=="Sochi"
foreach dir in "lat" "lon" {
	tostring `dir'_degree, replace
	tostring `dir'_minutes, replace
	replace `dir'_minutes = "0"+`dir'_minutes if length(`dir'_minutes)==1
	drop `dir'
	gen `dir' = `dir'_degree+"."+`dir'_minutes
	destring `dir', replace
}
duplicates drop
save "extras.dta", replace
use municip.dta, clear
#d ;
spmap using municipxy.dta if ID_1!=12, id(id_geography) point(data(extras) x(lon) y(lat) 
	fcolor(red) ocolor(black) prop(n_ave)) ;
#d cr
graph export "Figure A2 FINAL.png", replace
erase "extras.dta"
restore

****************************************************************************************************
** Figure A3. Fluctuations of City Ranks Across Cohorts.
****************************************************************************************************

egen rank1 = rank(SPbSU1), field
egen rank2 = rank(SPbSU2), field
egen rank3 = rank(SPbSU3), field
bysort rank1 rank2: egen n1 = count(rank1)
bysort rank3 rank2: egen n2 = count(rank2)
#d ;
twoway scatter rank3 rank2 [w=n2], mcolor(black) ylabel(0(50)250) graphr(c(white)) 
	xtitle("City Rank, # of SPbSU Students in Durov's Cohort")
	ytitle("City Rank, # of SPbSU Students One Cohort Before Durov") ;
#d cr
graph export "Figure A3-A FINAL.pdf" , replace as(pdf)
graph export "Figure A3-A FINAL.png" , replace
#d ;
twoway scatter rank1 rank2 [w=n1], mcolor(black) ylabel(0(50)250) graphr(c(white))
	xtitle("City Rank, # of SPbSU Students in Durov's Cohort")
	ytitle("City Rank, # of SPbSU Students One Cohort After Durov") ;
#d cr
graph export "Figure A3-B FINAL.pdf" , replace as(pdf)
graph export "Figure A3-B FINAL.png" , replace

****************************************************************************************************
** Figure A4. VK Penetration in November 2006 and SPbSU student cohorts.
****************************************************************************************************

$regtype logvk_l$threshold $control4 $SPcohorts , $err
#d ;
coefplot, keep(logspbsu*) xline(0) levels(90) coeflabels(
	logspbsu3="Log (SPbSU students), one cohort older than VK founder" 
	logspbsu2="Log (SPbSU students), same 5-year cohort as VK founder" 
	logspbsu1="Log (SPbSU students), one cohort younger than VK founder", 
	wrap(30) labsize(small)) title("Early VK penetration and coefficients for the number of SPbSU students over time", 
	size(medsmall) span) order(logspbsu3 logspbsu2 logspbsu1) xlabel(-0.1(0.05)0.1) ciopts(recast(rcap)) 
	graphr(c(white)) ;
#d cr
graph export "Figure A4 FINAL.png", replace

****************************************************************************************************
** Figure A5. Nonparametric Relationship between VK Penetration and Number of Protesters (In Shares).
****************************************************************************************************

lowess protesters_share vk_share if vk_share<1, xtitle("VK users, share of city population")	///
	ytitle("Average number of protesters, share of city population") note("") title("") graphr(c(white))
graph export "Figure A5 FINAL.png", replace

****************************************************************************************************
** Figure A6. Nonparametric Relationship between VK Penetration and Pro-Government Vote.
****************************************************************************************************

lowess statusquo1_11 vk_share if vk_share<1, xtitle("VK users, share of city population, 2011") ytitle("Vote Share for United Russia, 2011") note("") title("") graphr(c(white))
graph export "Figure A6-A FINAL.png", replace
lowess statusquo1_12 vk_share if vk_share<1, xtitle("VK users, share of city population, 2011") ytitle("Vote Share for Putin, 2012") note("") title("") graphr(c(white))
graph export "Figure A6-B FINAL.png", replace

****************************************************************************************************
** Figure A7. Reduced Form Coefficients for 65 Universities in Russia. 
****************************************************************************************************

gen uid = ""
matrix A=J(62,7,0)
local i = 1
#d ;
foreach uni in 6031023019 6125375295 6125435107 6125778995 6126047610 6127099247 6127372639 6127511036
	6127531910 6127635829 6127813096 6128014482 6128053135 6128617464 6129013718 6122414503 6123037594	
	6123164215 6123412058 6123423541 6123696809 6123762794 6124096593 6124173895 6124452690 6124715791	
	6092731190 6097039817 6097972182 6098215383 6098569210 6098587855 6098681282 6098755609 6099210662	
	6100262430 6100339981 6101871321 6107054710 6121645974 6121697957 6121766182 6122239141				
	33259781488832 33355668717820 36031934496984 38435165372446 38439866794215 39897906413669			
	42605707001990 42751705940124 42903316332740 42946246213757 43936604881138 44405365866567			
	44583074267321 45101231505568 45815027662947 47912022900758 48042296869082 48539956478002 50953037283387 { ;
#d cr
	qui reg logprot logU`uni'_2 logU`uni'_1 logU`uni'_3 $control4 , $err
	matrix A[`i',1] = _b[logU`uni'_2] // Durov's cohort
	matrix A[`i',2] = _b[logU`uni'_1] // One cohort younger or one cohort after Durov
	matrix A[`i',3] = _b[logU`uni'_3] // One cohort older or one cohort before Durov
	matrix A[`i',4] = _se[logU`uni'_2]
	matrix A[`i',5] = _se[logU`uni'_1]
	matrix A[`i',6] = _se[logU`uni'_3]
	matrix A[`i',7] = `i'
	qui replace uid = "`uni'" if _n == `i'
	local i = `i' + 1
}
capture drop A1 A2 A3 A4 A5 A6 A7
capture drop CDF_durov CDF_before CDF_after
svmat float A 

* Insert results for SPbSU -- column (5) in Table TA1
replace A1 = 0.253 if _n == 63
replace A2 = 0.152 if _n == 63
replace A3 = -0.075 if _n == 63
replace A7 = 63 if _n == 63
replace uid = "6095700118" if _n == 63

* Generate CDFs
rename A1 fs_coeff_durov
rename A2 fs_coeff_after
rename A3 fs_coeff_before
cumul fs_coeff_durov, gen(CDF_durov)
cumul fs_coeff_before, gen(CDF_before)
cumul fs_coeff_after, gen(CDF_after)

* Merge characteristics of universities
destring uid , replace
merge m:1 uid using "$path/socialmedia_data_unichars.dta", gen(_merge_unichars)
drop _merge_unichars	
	
* Build figures
#d ;
twoway (scatter CDF_durov fs_coeff_durov if top20==0, msymbol(X)) 
	(scatter CDF_durov fs_coeff_durov if top20==1) 
	(scatter CDF_durov fs_coeff_durov if saint_petersburg==1, msymbol (diamond) msize(small)), xline(0.253) 
	ylabel(0(0.1)1,angle(0)) xlabel(-0.8(0.2)0.8) ytitle("CDF") graphr(fcolor(white)) 
	xtitle("Reduced form coefficient for Durov's cohort") legend(label(2 "Top 20 Universities") 
	label(3 "Universities in Saint-Petersburg") label(1 "Other Universities") order(2 1 3) size(small)) ;
#d cr
graph export "Figure A7-A FINAL.png", replace

#d ;
twoway (scatter CDF_after fs_coeff_after if top20==0, msymbol(X)) 
	(scatter CDF_after fs_coeff_after if top20==1) 
	(scatter CDF_after fs_coeff_after if saint_petersburg==1, msymbol (diamond) msize(small)), xline(0.152) 
	ylabel(0(0.1)1,angle(0)) xlabel(-0.8(0.2)0.8) ytitle("CDF") graphr(fcolor(white)) 
	xtitle("Reduced form coefficient for cohort younger than Durov")  legend(label(2 "Top 20 Universities") 
	label(3 "Universities in Saint-Petersburg")	label(1 "Other Universities") order(2 1 3) size(small)) ;
#d cr    
graph export "Figure A7-B FINAL.png", replace

#d ;
twoway (scatter CDF_before fs_coeff_before if top20==0, msymbol(X)) 
	(scatter CDF_before fs_coeff_before if top20==1) 
	(scatter CDF_before fs_coeff_before if saint_petersburg==1, msymbol (diamond) msize(small)), xline(-0.075) 
	ylabel(0(0.1)1,angle(0)) xlabel(-0.8(0.2)0.8) ytitle("CDF") graphr(fcolor(white)) 
	xtitle("Reduced form coefficient for cohort older than Durov")  legend(label(2 "Top 20 Universities") 
	label(3 "Universities in Saint-Petersburg") label(1 "Other Universities") order(2 1 3) size(small)) ;
#d cr
graph export "Figure A7-C FINAL.png", replace

****************************************************************************************************
** Figure A10. Density of City Population.
****************************************************************************************************

hist pop , graphr(c(white)) xtitle("Population, in thousands") width(99.9) start(0)
graph export "Figure A10 FINAL.png", replace