clear all
set more off
global path="C:/Downloads/" // Set the path to the folder with replication files

****************************************************************************************************
** Load the city-level data and define global macro
****************************************************************************************************

use "$path/socialmedia_data_main.dta", clear
global SPcohorts="logspbsu2 logspbsu1 logspbsu3"
global SPcohortsnoDurov="logspbsu1 logspbsu3"
#d ;
global control_pop="pop pop_2 pop_3 pop_4 pop_5 " ;
global control0="" ;
global control1="$control_pop" ;
global control2="$control_pop  ac " ;
global control3="$control2 disttopiter disttomoscow city2 logwage11 lA20_24_y2010 lA25_29_y2010 
		lA30_34_y2010 lA35_39_y2010  lA40_44_y2010 lA45_49_y2010 lA50_more_y2010 he2010_A20_24 
		he2010_A25_29 he2010_A30_34 he2010_A35_39 he2010_A40_44 he2010_A45_49 he2010_A50_more" ;
global control4="$control3 University_exists ip_2011 logok2014 ef2010  educ2002" ;
global control4noOK="$control3 University_exists educ2002 ip_2011 ef2010" ;
global controlnopop4 = "ac disttopiter disttomoscow city2 logwage11 *_y2010 he2010_A20_24 he2010_A25_29 
	he2010_A30_34 he2010_A35_39 he2010_A40_44 he2010_A45_49 he2010_A50_more University_exists educ2002 
	ip_2011 logok2014 ef2010" ;
#d cr
// List controls for elections from different years as control5-control7
local controlall=""
forval i=5/7 {
	local y=95+(`i'-5)*4
	local y=`y'-int(`y'/100)*100
	local t="0`y'"
	local t=regexr("`t'","09","9")
	global control`i'="$control4 yabloko_`t' communists_`t' statusquo_`t' ldpr_`t' turnout_`t'"
	global controlnopop`i'="$controlnopop4 yabloko_`t' communists_`t' statusquo_`t' ldpr_`t' turnout_`t'"
	global control`i'noOK="$control4noOK yabloko_`t' communists_`t' statusquo_`t' ldpr_`t' turnout_`t'"
	global controlres`i'="$controlres4 yabloko_`t' communists_`t' statusquo_`t' ldpr_`t' turnout_`t'"
	local controlall="`controlall' yabloko_`t' communists_`t' statusquo_`t' ldpr_`t' turnout_`t'"
}
global control8="$control4 `controlall'"
global threshold="5"
global err=" cluster(okato_reg)"
global regtype="xi: reg"
global ivregtype="xi: ivreg2"
global proc=""
global weights = "[aweight=logpop]"
global logprot="log"
global logoldprot="logoldprot"
global loglabprot="log_Robertson_Total"
global dumprot="dum"
global dumoldprot="dumoldprot"
global dumlabprot="dum_Robertson_Total"
cd "$path/Figures" // Set the directory for storing figures

****************************************************************************************************
** Figure 1. VK Penetration in 2011 and the Number of SPbSU Students Over Time
****************************************************************************************************

qui $regtype logvk  $control4 $SPcohorts , $err
coefplot, keep(logspbsu*) xline(0) levels(90) coeflabels(logspbsu3="Log (SPbSU students), one cohort older than VK founder" logspbsu2="Log (SPbSU students), same 5-year cohort as VK founder"  logspbsu1="Log (SPbSU students), one cohort younger than VK founder", wrap(30) labsize(small)) order(logspbsu3 logspbsu2 logspbsu1) xlabel(-0.2(0.1)0.2) ciopts(recast(rcap)) graphregion(c(white))
graph export "Figure 1 FINAL.pdf", as(pdf) replace

****************************************************************************************************
** Figure 2. VK Penetration in 2011 and SPbSU student cohorts
****************************************************************************************************

* Graph for reduced form and protest dummy
qui $regtype dumprot $control4 $SPcohorts , $err
coefplot, keep(logspbsu*) xline(0) levels(90) coeflabels(logspbsu3="Log (SPbSU students), one cohort older than VK founder" logspbsu2="Log (SPbSU students), same 5-year cohort as VK founder"  logspbsu1="Log (SPbSU students), one cohort younger than VK founder", wrap(30) labsize(small)) title("A. Incidence of protests in 2011 and coefficients for the number of SPbSU students", size(medsmall) span) order(logspbsu3 logspbsu2 logspbsu1) xlabel(-0.1(0.05)0.1) ciopts(recast(rcap)) graphregion(color(white))
graph export "Figure 2A FINAL.pdf", as(pdf) replace

* Graph for reduced form prticipation
qui $regtype logprot $control4 $SPcohorts , $err
coefplot, keep(logspbsu*) xline(0) levels(90) coeflabels(logspbsu3="Log (SPbSU students), one cohort older than VK founder" logspbsu2="Log (SPbSU students), same 5-year cohort as VK founder"  logspbsu1="Log (SPbSU students), one cohort younger than VK founder", wrap(30) labsize(small)) title("B. Protest participation in 2011 and coefficients for the number of SPbSU students", size(medsmall) span) order(logspbsu3 logspbsu2 logspbsu1) xlabel(-0.5(0.25)0.5) ciopts(recast(rcap)) graphregion(color(white)) 
graph export "Figure 2B FINAL.pdf", as(pdf) replace

****************************************************************************************************
** Figure 3. Nonparametric Relationship between VK Penetration and Number of Protesters
****************************************************************************************************

lowess logprot logvk , xtitle("Log(VK users), 2011") ytitle("Log(Number of Protesters), 2011") note("") title("") graphr(c(white))
graph export "Figure 3 FINAL.pdf", as(pdf) replace

****************************************************************************************************
** Figure 4. Effect of Social Media on Protest Participation as a Function of Population Threshold
****************************************************************************************************

* Effect on the Incidence of Protest
matrix A=J(26,3,0)
forval i = 25(5)150 {
	capture drop logvkXpop ivXpop
	capture drop pop_ind
	gen pop_ind = (pop>`i')
	gen logvkXpop = logvk*pop_ind
	gen ivXpop = logspbsu2*pop_ind
	qui $ivregtype dumprot (logvk logvkXpop=logspbsu2 ivXpop) $SPcohortsnoDurov $control4 , $err
	matrix A[`i'/5-4,1] = _b[logvkXpop]
	matrix A[`i'/5-4,2] = _se[logvkXpop]
	matrix A[`i'/5-4,3] = `i'
}
capture drop n
capture drop A1 A2 A3 A4 A5 A6 A7
svmat A 
gen n=_n
gen A4 = A1-1.645*A2
gen A5 = A1+1.645*A2
gen A6 = A1-1.96*A2
gen A7 = A1+1.96*A2
#d ;
twoway (rarea A4 A5 A3, pstyle(ci) color(gs14)) (line A1 A3) 
	(line A6 A3 ,  lpattern(dash) lcolor(blue)) (line A7 A3 , lpattern(dash) lcolor(blue))
	(pci 0 25 0 150, color(black)) , xtitle("Population Thresholds") 
	ytitle("Log(VK) x 1[Population>Threshold]") graphr(c(white)) xlabel(30(10)150) 
	ylabel(-0.05(0.05)0.15) legend(off) name("Extensive_Margin", replace)
	title("Effect on the Incidence of Protests") ;
#d cr

* Effect on the Number of Protest Participants
matrix A=J(26,3,0)
forval i = 25(5)150 {
	capture drop logvkXpop ivXpop
	capture drop pop_ind
	gen pop_ind = (pop>`i')
	gen logvkXpop = logvk*pop_ind
	gen ivXpop = logspbsu2*pop_ind
	qui $ivregtype dumprot (logvk logvkXpop=logspbsu2 ivXpop) $SPcohortsnoDurov $control4 , $err
	matrix A[`i'/5-4,1] = _b[logvkXpop]
	matrix A[`i'/5-4,2] = _se[logvkXpop]
	matrix A[`i'/5-4,3] = `i'
}
capture drop n A1 A2 A3 A4 A5 A6 A7
svmat A 
gen n=_n
gen A4 = A1-1.645*A2
gen A5 = A1+1.645*A2
gen A6 = A1-1.96*A2
gen A7 = A1+1.96*A2
#d ;
twoway (rarea A4 A5 A3, pstyle(ci) color(gs14)) (line A1 A3) 
	(line A6 A3 ,  lpattern(dash) lcolor(blue)) (line A7 A3 , lpattern(dash) lcolor(blue))
	(pci 0 25 0 150, color(black)) , xtitle("Population Thresholds") 
	ytitle("Log(VK) x 1[Population>Threshold]") graphr(c(white)) xlabel(30(10)150) 
	legend(off) name("Intensive_Margin", replace)
	title("Effect on the Number of Protest Participants") ;
#d cr

* Compile a joint graph
graph combine Extensive_Margin Intensive_Margin ,  rows(1) cols(2) xsize(10) ysize(5) graphr(c(white))
graph export "Figure 4 FINAL.pdf", replace 

****************************************************************************************************
** Figure 5. Association between Social Media Fractionalization and Protests as a Function of Population
****************************************************************************************************

* Incidence of Protests
matrix A=J(26,3,0)
forval i = 25(5)150 {
	capture drop fractXpop lognetXpop
	capture drop pop_ind
	gen pop_ind = (pop>`i')
	gen fractXpop = fract11b*pop_ind
	gen lognetXpop = lognet11b*pop_ind
	qui $regtype dumprot fract11b fractXpop lognet11b lognetXpop $control4 , $err
	matrix A[`i'/5-4,1] = _b[fractXpop]
	matrix A[`i'/5-4,2] = _se[fractXpop]
	matrix A[`i'/5-4,3] = `i'
}
capture drop n
capture drop A1 A2 A3 A4 A5 A6 A7
svmat A 
gen n=_n
gen A4 = A1-1.645*A2
gen A5 = A1+1.645*A2
gen A6 = A1-1.96*A2
gen A7 = A1+1.96*A2
#d ;
twoway (rarea A4 A5 A3, pstyle(ci) color(gs14)) (line A1 A3) 
	(line A6 A3 ,  lpattern(dash) lcolor(blue)) (line A7 A3 , lpattern(dash) lcolor(blue))
	(pci 0 25 0 150, color(black)) , xtitle("Population Thresholds") 
	ytitle("Log(VK) x 1[Population>Threshold]") graphr(c(white)) xlabel(30(10)150) 
	legend(off) name("Extensive_Margin", replace)
	title("Incidence of Protests") ;
#d cr

* Number of Protest Participants
matrix A=J(26,3,0)
forval i = 25(5)150 {
	capture drop fractXpop lognetXpop
	capture drop pop_ind
	gen pop_ind = (pop>`i')
	gen fractXpop = fract11b*pop_ind
	gen lognetXpop = lognet11b*pop_ind
	qui $regtype logprot fract11b fractXpop lognet11b lognetXpop $control4 , $err
	matrix A[`i'/5-4,1] = _b[fractXpop]
	matrix A[`i'/5-4,2] = _se[fractXpop]
	matrix A[`i'/5-4,3] = `i'
}
capture drop n
capture drop A1 A2 A3 A4 A5 A6 A7
svmat A 
gen n=_n
gen A4 = A1-1.645*A2
gen A5 = A1+1.645*A2
gen A6 = A1-1.96*A2
gen A7 = A1+1.96*A2
#d ;
twoway (rarea A4 A5 A3, pstyle(ci) color(gs14)) (line A1 A3) 
	(line A6 A3 ,  lpattern(dash) lcolor(blue)) (line A7 A3 , lpattern(dash) lcolor(blue))
	(pci 0 25 0 150, color(black)) , xtitle("Population Thresholds") 
	ytitle("Log(VK) x 1[Population>Threshold]") graphr(c(white)) xlabel(30(10)150) 
	legend(off) name("Intensive_Margin", replace)
	title("Number of Protest Participants") ;
#d cr

* Compile a joint graph
graph combine Extensive_Margin Intensive_Margin ,  rows(1) cols(2) xsize(10) ysize(5) graphr(c(white))
graph export "Figure 5 FINAL.pdf", replace 