clear all
set more off
global path="C:/Downloads/" // Set the path to the folder with replication files

****************************************************************************************************
** Load the city-level data and define global macro
****************************************************************************************************

use "$path/socialmedia_data_main.dta", clear
global SPcohorts="logspbsu2 logspbsu1 logspbsu3"
global SPcohortsnoDurov="logspbsu1 logspbsu3"
#d ;
global control_pop="pop pop_2 pop_3 pop_4 pop_5 " ;
global control0="" ;
global control1="$control_pop" ;
global control2="$control_pop  ac " ;
global control3="$control2 disttopiter disttomoscow city2 logwage11 lA20_24_y2010 lA25_29_y2010 
		lA30_34_y2010 lA35_39_y2010  lA40_44_y2010 lA45_49_y2010 lA50_more_y2010 he2010_A20_24 
		he2010_A25_29 he2010_A30_34 he2010_A35_39 he2010_A40_44 he2010_A45_49 he2010_A50_more" ;
global control4="$control3 University_exists ip_2011 logok2014 ef2010  educ2002" ;
global control4noOK="$control3 University_exists educ2002 ip_2011 ef2010" ;
global controlnopop4 = "ac disttopiter disttomoscow city2 logwage11 *_y2010 he2010_A20_24 he2010_A25_29 
	he2010_A30_34 he2010_A35_39 he2010_A40_44 he2010_A45_49 he2010_A50_more University_exists educ2002 
	ip_2011 logok2014 ef2010" ;
#d cr
// List controls for elections from different years as control5-control7
local controlall=""
forval i=5/7 {
	local y=95+(`i'-5)*4
	local y=`y'-int(`y'/100)*100
	local t="0`y'"
	local t=regexr("`t'","09","9")
	global control`i'="$control4 yabloko_`t' communists_`t' statusquo_`t' ldpr_`t' turnout_`t'"
	global controlnopop`i'="$controlnopop4 yabloko_`t' communists_`t' statusquo_`t' ldpr_`t' turnout_`t'"
	global control`i'noOK="$control4noOK yabloko_`t' communists_`t' statusquo_`t' ldpr_`t' turnout_`t'"
	global controlres`i'="$controlres4 yabloko_`t' communists_`t' statusquo_`t' ldpr_`t' turnout_`t'"
	local controlall="`controlall' yabloko_`t' communists_`t' statusquo_`t' ldpr_`t' turnout_`t'"
}
global control8="$control4 `controlall'"
global threshold="5"
global err=" cluster(okato_reg)"
global regtype="xi: reg"
global ivregtype="xi: ivreg2"
global proc=""
global weights = "[aweight=logpop]"
global logprot="log"
global logoldprot="logoldprot"
global loglabprot="log_Robertson_Total"
global dumprot="dum"
global dumoldprot="dumoldprot"
global dumlabprot="dum_Robertson_Total"
cd "$path/Figures" // Set the directory for storing figures

****************************************************************************************************
** Figure TA1. First Stage Coefficients for 65 Universities in Russia.
****************************************************************************************************

* Calculate the first stage coefficients
gen uid = ""
matrix A=J(62,7,0)
local i = 1
#d ;
foreach uni in 6031023019 6125375295 6125435107 6125778995 6126047610 6127099247 6127372639 6127511036
	6127531910 6127635829 6127813096 6128014482 6128053135 6128617464 6129013718 6122414503 6123037594	
	6123164215 6123412058 6123423541 6123696809 6123762794 6124096593 6124173895 6124452690 6124715791	
	6092731190 6097039817 6097972182 6098215383 6098569210 6098587855 6098681282 6098755609 6099210662	
	6100262430 6100339981 6101871321 6107054710 6121645974 6121697957 6121766182 6122239141				
	33259781488832 33355668717820 36031934496984 38435165372446 38439866794215 39897906413669			
	42605707001990 42751705940124 42903316332740 42946246213757 43936604881138 44405365866567			
	44583074267321 45101231505568 45815027662947 47912022900758 48042296869082 48539956478002 50953037283387 { ;
#d cr
	qui reg logvk logU`uni'_2 logU`uni'_1 logU`uni'_3 $control4 , $err
	matrix A[`i',1] = _b[logU`uni'_2] // Durov's cohort
	matrix A[`i',2] = _b[logU`uni'_1] // One cohort younger or one cohort after Durov
	matrix A[`i',3] = _b[logU`uni'_3] // One cohort older or one cohort before Durov
	matrix A[`i',4] = _se[logU`uni'_2]
	matrix A[`i',5] = _se[logU`uni'_1]
	matrix A[`i',6] = _se[logU`uni'_3]
	matrix A[`i',7] = `i'
	qui replace uid = "`uni'" if _n == `i'
	local i = `i' + 1
}
capture drop A1 A2 A3 A4 A5 A6 A7
capture drop CDF_durov CDF_before CDF_after
svmat float A 

* Insert results for SPbSU -- column (5) in Table 1
replace A1 = 0.132 if _n == 63
replace A2 = -0.0333 if _n == 63
replace A3 = 0.0347 if _n == 63
replace A7 = 63 if _n == 63
replace uid = "6095700118" if _n == 63

* Generate CDFs
rename A1 fs_coeff_durov
rename A2 fs_coeff_after
rename A3 fs_coeff_before
cumul fs_coeff_durov, gen(CDF_durov)
cumul fs_coeff_before, gen(CDF_before)
cumul fs_coeff_after, gen(CDF_after)

* Merge characteristics of universities
destring uid , replace
merge m:1 uid using "$path/socialmedia_data_unichars.dta", gen(_merge_unichars)
drop _merge_unichars	
	
* Build figures
#d ;
twoway (scatter CDF_durov fs_coeff_durov if top20==0, msymbol(X)) 
	(scatter CDF_durov fs_coeff_durov if top20==1) 
	(scatter CDF_durov fs_coeff_durov if saint_petersburg==1, msymbol (diamond) msize(small)), xline(0.132) 
	ylabel(0(0.1)1,angle(0)) xlabel(-0.25(0.05)0.25) ytitle("CDF") graphr(fcolor(white)) 
	xtitle("First Stage coefficient for Durov's cohort") legend(label(2 "Top 20 Universities") 
	label(3 "Universities in Saint-Petersburg") label(1 "Other Universities") order(2 1 3) size(small)) ;
#d cr
graph export "Figure TA1-A FINAL.png", replace

#d ;
twoway (scatter CDF_after fs_coeff_after if top20==0, msymbol(X)) 
	(scatter CDF_after fs_coeff_after if top20==1) 
	(scatter CDF_after fs_coeff_after if saint_petersburg==1, msymbol (diamond) msize(small)), xline(-0.0333) 
	ylabel(0(0.1)1,angle(0)) xlabel(-0.25(0.05)0.25) ytitle("CDF") graphr(fcolor(white)) 
	xtitle("First Stage coefficient for cohort younger than Durov")  legend(label(2 "Top 20 Universities") 
	label(3 "Universities in Saint-Petersburg")	label(1 "Other Universities") order(2 1 3) size(small)) ;
#d cr    
graph export "Figure TA1-B FINAL.png", replace

#d ;
twoway (scatter CDF_before fs_coeff_before if top20==0, msymbol(X)) 
	(scatter CDF_before fs_coeff_before if top20==1) 
	(scatter CDF_before fs_coeff_before if saint_petersburg==1, msymbol (diamond) msize(small)), xline(0.0347) 
	ylabel(0(0.1)1,angle(0)) xlabel(-0.25(0.05)0.25) ytitle("CDF") graphr(fcolor(white)) 
	xtitle("First Stage coefficient for cohort older than Durov")  legend(label(2 "Top 20 Universities") 
	label(3 "Universities in Saint-Petersburg") label(1 "Other Universities") order(2 1 3) size(small)) ;
#d cr
graph export "Figure TA1-C FINAL.png", replace

****************************************************************************************************
** Figure TA2. Magnitude of the Effect of Social Media on Voting Outcomes as a Function of Population Threshold.
****************************************************************************************************

* Effect on the Electoral Support for United Russia in 2011
matrix A=J(26,3,0)
forval i = 25(5)150 {
	capture drop logvkXpop ivXpop
	capture drop pop_ind
	gen pop_ind = (pop>`i')
	gen logvkXpop = logvk*pop_ind
	gen ivXpop = logspbsu2*pop_ind
	qui $ivregtype statusquo1_11 (logvk logvkXpop=logspbsu2 ivXpop) $SPcohortsnoDurov $control4 $weights, $err
	matrix A[`i'/5-4,1] = _b[logvkXpop]
	matrix A[`i'/5-4,2] = _se[logvkXpop]
	matrix A[`i'/5-4,3] = `i'
}
capture drop A4 A5 A6 A7
capture drop n
svmat A 
gen n=_n
gen A4 = A1-1.645*A2
gen A5 = A1+1.645*A2
gen A6 = A1-1.96*A2
gen A7 = A1+1.96*A2
#d ;
twoway (rarea A4 A5 A3, pstyle(ci) color(gs14)) (line A1 A3) 
	(line A6 A3 ,  lpattern(dash) lcolor(blue)) (line A7 A3 , lpattern(dash) lcolor(blue))
	(pci 0 25 0 150, color(black)) , xtitle("Population Thresholds") 
	ytitle("Log(VK) x 1[Population>Threshold]") graphr(c(white)) xlabel(30(10)150) 
	legend(off) name("Extensive_Margin", replace)
	title("Effect on the Voting Share for United Russia, 2011") ;
#d cr

* Effect on the Electoral Support for Putin in 2012
matrix A=J(26,3,0)
forval i = 25(5)150 {
	capture drop logvkXpop ivXpop
	capture drop pop_ind
	gen pop_ind = (pop>`i')
	gen logvkXpop = logvk*pop_ind
	gen ivXpop = logspbsu2*pop_ind
	qui $ivregtype statusquo1_12 (logvk logvkXpop=logspbsu2 ivXpop) $SPcohortsnoDurov $control4 $weights, $err
	matrix A[`i'/5-4,1] = _b[logvkXpop]
	matrix A[`i'/5-4,2] = _se[logvkXpop]
	matrix A[`i'/5-4,3] = `i'
}
capture drop A1 A2 A3 A4 A5 A6 A7
capture drop n
svmat A 
gen n=_n
gen A4 = A1-1.645*A2
gen A5 = A1+1.645*A2
gen A6 = A1-1.96*A2
gen A7 = A1+1.96*A2
#d ;
twoway (rarea A4 A5 A3, pstyle(ci) color(gs14)) (line A1 A3) 
	(line A6 A3 ,  lpattern(dash) lcolor(blue)) (line A7 A3 , lpattern(dash) lcolor(blue))
	(pci 0 25 0 150, color(black)) , xtitle("Population Thresholds") 
	ytitle("Log(VK) x 1[Population>Threshold]") graphr(c(white)) xlabel(30(10)150) 
	legend(off) name("Intensive_Margin", replace)
	title("Effect on the Voting Share for Putin, 2012") ;
#d cr

* Compile a joint graph
graph combine Extensive_Margin Intensive_Margin ,  rows(2) cols(1) xsize(6) ysize(10) graphr(c(white))
graph export "Figure TA2 FINAL.png", replace 
