clear all
set more off
global path="C:/Downloads/" // Set the path to the folder with replication files

****************************************************************************************************
** Load the city-level data and define global macro
****************************************************************************************************

use "$path/socialmedia_data_main.dta", clear
global SPcohorts="logspbsu2 logspbsu1 logspbsu3"
global SPcohortsnoDurov="logspbsu1 logspbsu3"
#d ;
global control_pop="pop pop_2 pop_3 pop_4 pop_5 " ;
global control0="" ;
global control1="$control_pop" ;
global control2="$control_pop  ac " ;
global control3="$control2 disttopiter disttomoscow city2 logwage11 lA20_24_y2010 lA25_29_y2010 
		lA30_34_y2010 lA35_39_y2010  lA40_44_y2010 lA45_49_y2010 lA50_more_y2010 he2010_A20_24 
		he2010_A25_29 he2010_A30_34 he2010_A35_39 he2010_A40_44 he2010_A45_49 he2010_A50_more" ;
global control4="$control3 University_exists ip_2011 logok2014 ef2010  educ2002" ;
global control4noOK="$control3 University_exists educ2002 ip_2011 ef2010" ;
global controlnopop4 = "ac disttopiter disttomoscow city2 logwage11 *_y2010 he2010_A20_24 he2010_A25_29 
	he2010_A30_34 he2010_A35_39 he2010_A40_44 he2010_A45_49 he2010_A50_more University_exists educ2002 
	ip_2011 logok2014 ef2010" ;
#d cr
// List controls for elections from different years as control5-control7
local controlall=""
forval i=5/7 {
	local y=95+(`i'-5)*4
	local y=`y'-int(`y'/100)*100
	local t="0`y'"
	local t=regexr("`t'","09","9")
	global control`i'="$control4 yabloko_`t' communists_`t' statusquo_`t' ldpr_`t' turnout_`t'"
	global controlnopop`i'="$controlnopop4 yabloko_`t' communists_`t' statusquo_`t' ldpr_`t' turnout_`t'"
	global control`i'noOK="$control4noOK yabloko_`t' communists_`t' statusquo_`t' ldpr_`t' turnout_`t'"
	global controlres`i'="$controlres4 yabloko_`t' communists_`t' statusquo_`t' ldpr_`t' turnout_`t'"
	local controlall="`controlall' yabloko_`t' communists_`t' statusquo_`t' ldpr_`t' turnout_`t'"
}
global control8="$control4 `controlall'"
global threshold="5"
global err=" cluster(okato_reg)"
global regtype="xi: reg"
global ivregtype="xi: ivreg2"
global proc=""
global weights = "[aweight=logpop]"
global logprot="log"
global logoldprot="logoldprot"
global loglabprot="log_Robertson_Total"
global dumprot="dum"
global dumoldprot="dumoldprot"
global dumlabprot="dum_Robertson_Total"
cd "$path/Tables" // Set the directory for storing tables

****************************************************************************************************
** Table A1. Summary Statistics.
****************************************************************************************************

#d ;
fsum dumprot dumoldprot dumoldprot_dem dummonprot dum_Robertson_Total logprot logoldprot logoldprot_dem logmonprot 
	log_Robertson_Total logvk logvk_l5 logvk13okt logok2014 logfb13 $SPcohorts ip_2011 pop ac city2 disttopiter 
	disttomoscow  logwage11 lA20_24_y2010 lA25_29_y2010 lA30_34_y2010 lA35_39_y2010  lA40_44_y2010 lA45_49_y2010 
	lA50_more_y2010 educ2002 he2010_A20_24 he2010_A25_29 he2010_A30_34 he2010_A35_39 he2010_A40_44 he2010_A45_49 
	he2010_A50_more University_exists ef2010 statusquo_95 statusquo_99 statusquo_03 statusquo1_07 statusquo1_11 
	statusquo1_16 Votes_1_1996 Votes_1_1996_2nd statusquo1_00 statusquo1_04 statusquo1_08 statusquo1_12 yabloko_95 
	yabloko_99 yabloko_03 communists_95 communists_99 communists_03 ldpr_95 ldpr_99 ldpr_03 Votes_4_1996 Votes_3_2000 
	hakamada1_04 Votes_2_1996 Votes_2_1996_2nd Votes_2_2000 haritonov1_04 Votes_3_1996 tuleev1_00 glaziev1_04 
	against_95 Votes_11_1996 Votes_11_1996_2nd against_99 against1_00 against_03 turnout_95 turnout1996 turnout1996_2nd 
	turnout_99 turnout1_00 turnout_03 turnout1_04 , stat(n min median mean sd max) ;
#d cr 

****************************************************************************************************
** Table A2. Variable Means by Quartile of VK Penetration
****************************************************************************************************

sum vk_share , d
gen quartile = 1 if vk_share<r(p25)
replace quartile = 2 if vk_share>=r(p25) & vk_share<r(p50)
replace quartile = 3 if vk_share>=r(p50) & vk_share<r(p75)
replace quartile = 4 if vk_share>=r(p75)
forval i = 1/4 {
	#d ;
	fsum dumprot dumoldprot dumoldprot_dem dummonprot dum_Robertson_Total logprot logoldprot logoldprot_dem logmonprot 
		log_Robertson_Total logvk logvk_l5 logvk13okt logok2014 logfb13 $SPcohorts ip_2011 pop ac city2 disttopiter 
		disttomoscow  logwage11 lA20_24_y2010 lA25_29_y2010 lA30_34_y2010 lA35_39_y2010  lA40_44_y2010 lA45_49_y2010 
		lA50_more_y2010 educ2002 he2010_A20_24 he2010_A25_29 he2010_A30_34 he2010_A35_39 he2010_A40_44 he2010_A45_49 
		he2010_A50_more University_exists ef2010 statusquo_95 statusquo_99 statusquo_03 statusquo1_07 statusquo1_11 
		statusquo1_16 Votes_1_1996 Votes_1_1996_2nd statusquo1_00 statusquo1_04 statusquo1_08 statusquo1_12 yabloko_95 
		yabloko_99 yabloko_03 communists_95 communists_99 communists_03 ldpr_95 ldpr_99 ldpr_03 Votes_4_1996 Votes_3_2000 
		hakamada1_04 Votes_2_1996 Votes_2_1996_2nd Votes_2_2000 haritonov1_04 Votes_3_1996 tuleev1_00 glaziev1_04 
		against_95 Votes_11_1996 Votes_11_1996_2nd against_99 against1_00 against_03 turnout_95 turnout1996 turnout1996_2nd 
		turnout_99 turnout1_00 turnout_03 turnout1_04 if quartile==`i' , stat(n min median mean sd max) ;
	#d cr 
}

****************************************************************************************************
** Table A3. Distribution of Size of SPbSU Student Cohorts
****************************************************************************************************

tab SPbSU2
tab SPbSU3
tab SPbSU1

****************************************************************************************************
** Table A4. Correlation Between City Ranks Across Cohorts
****************************************************************************************************

egen rank1 = rank(SPbSU1), field
egen rank2 = rank(SPbSU2), field
egen rank3 = rank(SPbSU3), field
pwcorr rank* if (SPbSU1!=0 | SPbSU2!=0 | SPbSU3!=0)

****************************************************************************************************
** Table A5. Determinants of Early VK Penetration
****************************************************************************************************

local opt="replace"
global outtable="Table A5 FINAL.xls"
local oldprot=""
local dec=4
foreach control in "control0" "control1" "control2" "control3" "control4" "control5" "control6" "control7" {
	qui $regtype logvk_l5 $SPcohorts $`control' `oldprot' , $err 
	qui test logspbsu2=logspbsu1=logspbsu3
	local p_value_cohorts=r(p)
	qui test logspbsu2=logspbsu3
	local p_value_cohorts_old=r(p)
	qui test logspbsu2=logspbsu1
	local p_value_cohorts_young=r(p)
	qui sum logvk_l5 
	local mean=r(mean)
	local sd=r(sd)
	outreg2 using "$outtable", bracket  drop(pop* lA* he* educ* yabloko* communists* statusquo* ldpr* turnout* ) `opt' label dec(`dec') nocons noaster addstat("mean", `mean', "sd", `sd', "p-value equality all cohorts", `p_value_cohorts', "p-value equality with young cohort",  `p_value_cohorts_young',	"p-value equality with old cohort", `p_value_cohorts_old')
	local opt="append"
}

****************************************************************************************************
** Table A6. Baseline Results for Saturday (December 10, 2011) Protests Only
****************************************************************************************************

local opt="replace"
global outtable="Table A6 FINAL.xls"
foreach depvar in  dumprot logprot  {
	foreach control in "control4" "control5" "control6" "control7" {
		qui $ivregtype `depvar' (logvk=logspbsu2) $SPcohortsnoDurov  $`control' `oldprot' if OKATO!="07401" & OKATO!="19430" & OKATO!="53423" & OKATO!="57401", $err
		local FKP=e(widstat)
		qui weakivtest
		local F0=r(F_eff)
		qui sum `depvar' 
		local mean=r(mean)
		local sd=r(sd)
		#d ;
		outreg2 using "$outtable", bracket keep(logvk logspbsu1 logspbsu3) noaster 
			addstat("K-P F-stat", `FKP',"Effective F-statistics",`F0') `opt' label dec(3) nocons 
			addtext("mean", `mean', "sd", `sd') ;
		#d cr
		local opt="append"
	}
}

****************************************************************************************************
** Table A7. VK Penetration and Protest Participation in 2011 (Spatial Standard Errors)
****************************************************************************************************

* net install acreg, from(https://acregstata.weebly.com/uploads/2/9/1/6/29167217) replace // If not installed
local opt = "replace"
global outtable = "Table A7 FINAL.xls"
foreach depvar in  dumprot logprot  {
	foreach control in "control4" "control5" "control6" "control7" {
		qui acreg `depvar' $`control' $SPcohortsnoDurov (logvk=logspbsu2) , latitude(lat_dec) longitude(lon_dec) dist(500) spatial
		local FKP=e(widstat)
		outreg2 using "$outtable", bracket keep(logvk logspbsu1 logspbsu3) addstat("K-P F-stat", `FKP') `opt' label dec(3) nocons noaster 
		local opt = "append"
	}
}

****************************************************************************************************
** Table A8. IV Probit and Negative Binomial Models
****************************************************************************************************

set seed 123456789
local opt="replace"
global outtable="Table A8 FINAL.xls"
foreach control in "control4" "control5" "control6" "control7" {
	ivprobit dumprot (logvk=logspbsu2) $SPcohortsnoDurov  $`control' , vce(cluster okato_reg) dif iterate(5000)
	margins, dydx(logvk $SPcohortsnoDurov ) continuous predict(pr) post
	outreg2 using "$outtable", bracket `opt' label dec(3)  
	local opt="append"
}

foreach control in "control4" "control5" "control6" "control7" {
	cap program drop mypoisson
		program mypoisson
			args depvar trtm instr
			qui {
				regress `trtm' `instr' $SPcohortsnoDurov $`control'
				tempvar resid 
				predict `resid', residual
				nbreg `depvar' `trtm' `resid' $SPcohortsnoDurov $`control' , iterate(5000)
			}
		end
	n: bootstrap _b[logvk] _b[logspbsu1] _b[logspbsu3] : mypoisson n_ave_1000 logvk logspbsu2 
	outreg2 using "$outtable", bracket drop(pop* lA* he* educ* yabloko* communists* statusquo* ldpr* turnout*  against* )  `opt' label dec(3) nocons
}

/* Without bootstrap
local opt="replace"
global outtable="Table A8 FINAL.xls"
foreach control in "control4" "control5" "control6" "control7"  {
	regress logvk  logspbsu2 $SPcohortsnoDurov $`control'
	tempvar resid 
	predict `resid', residual
	qui nbreg n_ave_1000  logvk `resid' $SPcohortsnoDurov $`control', iterate(100) vce(cluster okato_reg) 
	outreg2 using "$outtable", bracket keep(logvk logspbsu1 logspbsu3) `opt' label dec(3) nocons noaster
	local opt="append"
}
*/

****************************************************************************************************
** Table A9. Weak IV Robust Confidence Intervals
****************************************************************************************************

** Chernozhukov and Hansen (2008) -- no ready-to-go code, so we coded it ourselves
* Protest outcomes: no population weights
set matsize 10000
foreach yvar in "dumprot" "logprot" {
	foreach control in "control4" "control5" "control6" "control7" { 
		qui reg `yvar' $SPcohortsnoDurov $`control'
		qui predict yh, res
		qui reg logvk $SPcohortsnoDurov $`control'
		qui predict xh, res
		qui reg logspbsu2 $SPcohortsnoDurov $`control'
		qui predict zh, res
		global nrep = 2000
		matrix beta = J($nrep,1,1)
		matrix alpha = J($nrep,1,1)
		matrix var = J($nrep,1,1)
		matrix w_s = J($nrep,1,1)
		qui gen yhat = .
		* Go over a grid for b in [-10, 10]
		scalar b = -10
		forval i=1/$nrep {
			scalar b = b + 20/$nrep
			qui replace yhat = yh-xh*b
			qui reg yhat zh , nocons cluster(okato_reg)
			matrix beta[`i',1] = b
			matrix alpha[`i',1] = _b[zh]
			matrix var[`i',1] = (_se[zh])^2
			matrix w_s[`i',1] = alpha[`i',1]^2 / var[`i',1]
		}
		qui svmat w_s, names(w_s)
		qui svmat beta, names(beta)
		qui gen ci = (w_s <= 3.84)
		qui sum beta if ci==1
		display "(" r(min) ";" r(max) ")"
		drop w_s beta ci yh xh zh yhat
	}
}
* Voting outcomes: with population weights
foreach yvar in "statusquo1_11" "statusquo1_12" {
	foreach control in "control4" "control5" "control6" "control7" { 
		qui reg `yvar' $SPcohortsnoDurov $`control' $weights
		qui predict yh, res
		qui reg logvk $SPcohortsnoDurov $`control' $weights
		qui predict xh, res
		qui reg logspbsu2 $SPcohortsnoDurov $`control' $weights
		qui predict zh, res
		global nrep = 2000
		matrix beta = J($nrep,1,1)
		matrix alpha = J($nrep,1,1)
		matrix var = J($nrep,1,1)
		matrix w_s = J($nrep,1,1)
		qui gen yhat = .
		* Go over a grid for b in [-10, 10]
		scalar b = -10
		forval i=1/$nrep {
			scalar b = b + 20/$nrep
			qui replace yhat = yh-xh*b
			qui reg yhat zh $weights, nocons $err
			matrix beta[`i',1] = b
			matrix alpha[`i',1] = _b[zh]
			matrix var[`i',1] = (_se[zh])^2
			matrix w_s[`i',1] = alpha[`i',1]^2 / var[`i',1]
		}
		qui svmat w_s, names(w_s)
		qui svmat beta, names(beta)
		qui gen ci = (w_s <= 3.84)
		qui sum beta if ci==1
		display "(" r(min) ";" r(max) ")"
		drop w_s beta ci yh xh zh yhat
	}
}

** Finlay and Magnusson (2009) -- "ssc install weakiv"
* Protest outcomes: no population weights
foreach yvar in "dumprot" "logprot" {
	foreach control in "control4" "control5" "control6" "control7" { 
		qui ivreg2 `yvar' (logvk=logspbsu2) $SPcohortsnoDurov $`control' , $err
		qui weakiv, lm usegrid gridpoints(500) gridmin(-1) gridmax(9)
		display e(ar_cset)
	}
}
* Voting outcomes: with population weights
foreach yvar in "statusquo1_11" "statusquo1_12" {
	foreach control in "control4" "control5" "control6" "control7" { 
		qui ivreg2 `yvar' (logvk=logspbsu2) $SPcohortsnoDurov $`control' $weights , $err
		qui weakiv, lm usegrid gridpoints(500) gridmin(-1) gridmax(9)
		display e(ar_cset)
	}
}

** Mikusheva (2010) -- "search condivreg"
* Protest outcomes: no population weights
foreach yvar in "dumprot" "logprot" {
	foreach control in "control4" "control5" "control6" "control7" { 
		qui reg `yvar' $SPcohortsnoDurov $`control'
		qui predict yh, res
		qui reg logvk $SPcohortsnoDurov $`control'
		qui predict xh, res
		qui reg logspbsu2 $SPcohortsnoDurov $`control'
		qui predict zh, res
		condivreg yh (xh = zh), liml interval
		qui drop yh xh zh
	}
}
* Voting outcomes: with population weights
foreach yvar in "statusquo1_11" "statusquo1_12" {
	foreach control in "control4" "control5" "control6" "control7" { 
		qui reg `yvar' $SPcohortsnoDurov $`control' $weights
		qui predict yh, res
		qui reg logvk $SPcohortsnoDurov $`control' $weights
		qui predict xh, res
		qui reg logspbsu2 $SPcohortsnoDurov $`control' $weights
		qui predict zh, res
		condivreg yh (xh = zh), liml interval
		qui drop yh xh zh
	}
}

****************************************************************************************************
** Table A10. Threshold Model. Protest Participation as a Function of VK Penetration.
****************************************************************************************************

set seed 123456789
eststo clear
global outtable="Table A10 FINAL.csv"
local dep="vk_share"
foreach depvar in dumprot logprot {
	foreach control in "control4" "control5" "control6" "control7"   {
		local contr_nl=""
		local i=1
		foreach var of varlist $`control' {
			local contr_nl="`contr_nl' {c`i'}*`var'+"
			local i=`i'+1
		}
		qui n: eststo: nl (`depvar' = {b1}*`dep'+{bb1}*(sign(`dep'-{t})+(sign(`dep'-{t})^2))*0.5*(`dep'-{t})+{b2}*logspbsu1+{b3}*logspbsu3+`contr_nl' {b0}), vce(cluster okato_reg) initial(b1 1 bb1 2 t 0.25)	
	}
}
local dep="logvk"
foreach depvar in dumprot logprot {
	foreach control in "control4" "control5" "control6" "control7"   {
		local contr_nl=""
		local i=1
		foreach var of varlist $`control' {
			local contr_nl="`contr_nl' {c`i'}*`var'+"
			local i=`i'+1
		}
		qui n: eststo: nl (`depvar' = {b1}*`dep'+{bb1}*(sign(`dep'-{t})+(sign(`dep'-{t})^2))*0.5*(`dep'-{t})+{b2}*logspbsu1+{b3}*logspbsu3+`contr_nl' {b0}), vce(cluster okato_reg) initial(b1 1 bb1 2 t 10)	
	}
}
esttab using "$outtable", replace se nostar b(%8.3f)

****************************************************************************************************
** Table A11. VK Penetration, Turnout, and Invalid Votes
****************************************************************************************************

* Turnout
local opt="replace"
global outtable="Table A11 FINAL.xls"
foreach depvar in turnout1_07 turnout1_08 turnout1_11 turnout1_12 turnout1_16 {
	foreach control in "control4" "control5" "control6" "control7" {
		qui $ivregtype `depvar' (logvk=logspbsu2) $SPcohortsnoDurov  $`control' $weights, $err
		local FKP=e(widstat)
		qui weakivtest
		local F0=r(F_eff)
		outreg2 using "$outtable", bracket keep(logvk logspbsu1 logspbsu3) addstat("K-P F-stat", `FKP',"Effective F-statistics",`F0') `opt' label dec(3) nocons noaster
		local opt="append"
	}
}	

* Invalid ballots
foreach depvar in ballots_invalid_sh_07 ballots_invalid_sh_08 ballots_invalid_sh_11 ballots_invalid_sh_12 ballots_invalid_sh_16 {
	foreach control in "control4" "control5" "control6" "control7" {
		qui $ivregtype `depvar' (logvk=logspbsu2) $SPcohortsnoDurov  $`control' $weights, $err
		local FKP=e(widstat)
		qui weakivtest
		local F0=r(F_eff)
		outreg2 using "$outtable", bracket keep(logvk logspbsu1 logspbsu3) addstat("K-P F-stat", `FKP',"Effective F-statistics",`F0') `opt' label dec(3) nocons noaster
		local opt="append"
	}	
}

****************************************************************************************************
** Table A12. VK and Penetration of Odnoklassniki
****************************************************************************************************

local opt="replace"
global outtable="Table A12 FINAL.xls"
foreach var in logvk_l5 logvk_l50 logvk_l100 logvk {
	qui $regtype logok2014 `var' $control4noOK , $err	
	outreg2 using "$outtable", bracket drop(pop* lA* he* educ* yabloko* communists* statusquo* ldpr* turnout* ) `opt' label dec(3) nocons noaster
	local opt="append"
}
foreach control in "control4noOK" "control5noOK" "control6noOK" "control7noOK" {
	qui $regtype logok2014 $SPcohorts $`control' , $err
	outreg2 using "$outtable", bracket drop(pop* lA* he* educ* yabloko* communists* statusquo* ldpr* turnout* ) `opt' label dec(3) nocons noaster
	local opt="append"
}	

****************************************************************************************************
** Table A13. Baseline Results with Alternative Cohort Definitions
****************************************************************************************************

local opt="replace"
global outtable="Table A13 FINAL.xls"
forval i = 1/4 {
	forval j = 1/4 {
		foreach depvar in "dumprot" {
			qui $ivregtype `depvar' (logvk=logspbsu2_exp`i'`j') logspbsu1_exp`i'`j' logspbsu3_exp`i'`j' $control4 , $err
			local FKP=e(widstat)
			qui weakivtest
			local F0=r(F_eff)
			outreg2 using "$outtable", bracket keep(logvk logspbsu1_exp`i'`j' logspbsu3_exp`i'`j') addstat("K-P F-stat", `FKP',"Effective F-statistics",`F0') `opt' label dec(3) nocons noaster
			local opt="append"
		}
	}	
}

****************************************************************************************************
** Table A14. Baseline Results with Cohorts Defined Based on Starting Year of Study at SpbSU.
****************************************************************************************************

local opt="replace"
global outtable="Table A14 FINAL.xls"
foreach depvar in dumprot logprot  {
	foreach control in "control4" "control5" "control6" "control7" {
		qui $ivregtype `depvar' (logvk=logspbsu7_5y_new) logspbsu8_5y_new logspbsu6_5y_new $`control' , $err
		local FKP=e(widstat)
		qui weakivtest
		local F0=r(F_eff)
		outreg2 using "$outtable", bracket keep(logvk logspbsu8_5y_new logspbsu6_5y_new) addstat("K-P F-stat", `FKP',"Effective F-statistics",`F0') `opt' label dec(3) nocons noaster
		local opt="append"
	}
}

****************************************************************************************************
** Table A15. Online protest communities and protest participation. OLS estimates.
****************************************************************************************************

local opt="replace"
global outtable="Table A15 FINAL.xls"
local var="loggr1"
foreach depvar in logprot dumprot {
	foreach control in "control4" "control5" "control6" "control7" {
		if regexm("`depvar'","dumprot") {
			local oldprot=""
		}
		qui $regtype `depvar'  `var'  $`control' `oldprot' , $err
		local F0=r(F_eff)
		outreg2 using "$outtable", bracket keep(loggr1) `opt' label dec(3) nocons noaster
		local opt="append"
	}	
}

****************************************************************************************************
** Table A16. Baseline Results with Population Weights
****************************************************************************************************

local opt="replace"
global outtable="Table A16 FINAL.xls"
foreach depvar in dumprot logprot  {
	foreach control in "control4" "control5" "control6" "control7" {
		qui $ivregtype `depvar' (logvk=logspbsu2) $SPcohortsnoDurov $`control' $weights , $err
		local FKP=e(widstat)
		qui weakivtest
		local F0=r(F_eff)
		qui sum `depvar'
		local mean=r(mean)
		local sd=r(sd)
		#d ;
		outreg2 using "$outtable", bracket drop(lA* he* educ* yabloko* communists* statusquo* ldpr* turnout* 
			against* ) addstat("K-P F-stat", `FKP',"Effective F-statistics",`F0') `opt' label dec(3) nocons 
			addtext("mean", `mean', "sd", `sd') noaster ;
		#d cr
		local opt="append"
	}
}

****************************************************************************************************
** Table A17. Heterogeneity of the VK Penetration Effect on Protests.
****************************************************************************************************

local opt="replace"
foreach var in wage sc_trust educ {
	sum `var' , d
	local `var'_med=r(p50)
}
global outtable="Table A17 FINAL.xls"
foreach cond in "wage<=`wage_med'" "wage>`wage_med'" "sc_trust<`sc_trust_med'" "sc_trust>`sc_trust_med'&sc_trust!=." "educ<=`educ_med'" "educ>`educ_med'" {
	qui $ivregtype logprot (logvk=logspbsu2) $SPcohortsnoDurov  $control4  if `cond', $err
	qui weakivtest
	local F0=r(F_eff)
	outreg2 using "$outtable", bracket keep(logvk logspbsu1 logspbsu3) addstat("Effective F-statistics",`F0') `opt' label dec(3) nocons noaster
	local opt="append"
}

****************************************************************************************************
** Table A18. Robustness of Fractionalization Results to Partial Overlap
****************************************************************************************************

local opt="replace"
global outtable="Table A18 FINAL.xls"
foreach depvar in logprot dumprot {
	forval ovlp = 0(10)90 {
		lab var fract11b_`ovlp'ovlp "Fract"
		qui $regtype `depvar' fract11b_`ovlp'ovlp lognet11b $control4 if pop>100, $err
		outreg2 using "$outtable", bracket keep(fract11b_`ovlp'ovlp lognet11b) `opt' label dec(3) nocons noaster
		local opt="append"
	}
}	

****************************************************************************************************
** Table A19. Fractionalization of Networks and Protest Participation. Controlling for VK and FB separately.
****************************************************************************************************

local opt="replace"
global outtable="Table A19 FINAL.xls"
foreach depvar in logprot dumprot {
	foreach cond in  "" "if pop>100"  {
		foreach control in "control4" "control5" "control6" "control7" {
			qui $regtype  `depvar' fract11b logfb11b logvk $`control' `cond' , $err
			qui sum `depvar' if e(sample)
			local mean=r(mean)
			local sd=r(sd)
			outreg2 using "$outtable", bracket keep(fract11b logfb11b logvk) `opt' label dec(3) nocons addstat("mean", `mean', "sd", `sd') noaster
			local opt="append"
		}	
	}
}	

****************************************************************************************************
** Table A20. Fractionalization of Networks and Voting Outcomes.
****************************************************************************************************

local opt="replace"
global outtable="Table A20 FINAL.xls"
foreach depvar in statusquo1_11 statusquo1_12 statusquo1_16 {
	foreach cond in  "" "if pop>100"  {
		foreach control in "control4" "control5" "control6" "control7" {
			qui $regtype  `depvar' fract11b lognet11b $`control' `cond' $weights, $err
			qui sum `depvar' if e(sample)
			local mean=r(mean)
			local sd=r(sd)
			outreg2 using "$outtable", bracket keep(fract11b lognet11b) `opt' label dec(3) nocons addstat("mean", `mean', "sd", `sd') noaster
			local opt="append"
		}	
	}
}	

****************************************************************************************************
** Table A21. Budgets.
****************************************************************************************************

local opt="replace"
global outtable="Table A21 FINAL.xls"
foreach var in inie_transferti sobstvennie_dohodi rashodi_budgeta_vsego {
	foreach y in 09 10 11 12 13 14 {
		qui $ivregtype l`var'`y' (logvk=logspbsu2) $SPcohortsnoDurov $control4 statusquo_07 turnout_07 communists_07 yabloko_07  l`var'08 , $err
		qui weakivtest
		local F0=r(F_eff)
		outreg2 using "$outtable", bracket keep(logvk) addstat("Effective F-statistics",`F0') `opt' label dec(3) nocons noaster
		local opt="append"
	}
}