clear all
set more off
global path="C:/Downloads/" // Set the path to the folder with replication files

****************************************************************************************************
** Load the city-level data and define global macro
****************************************************************************************************

use "$path/socialmedia_data_main.dta", clear
global SPcohorts="logspbsu2 logspbsu1 logspbsu3"
global SPcohortsnoDurov="logspbsu1 logspbsu3"
#d ;
global control_pop="pop pop_2 pop_3 pop_4 pop_5 " ;
global control0="" ;
global control1="$control_pop" ;
global control2="$control_pop  ac " ;
global control3="$control2 disttopiter disttomoscow city2 logwage11 lA20_24_y2010 lA25_29_y2010 
		lA30_34_y2010 lA35_39_y2010  lA40_44_y2010 lA45_49_y2010 lA50_more_y2010 he2010_A20_24 
		he2010_A25_29 he2010_A30_34 he2010_A35_39 he2010_A40_44 he2010_A45_49 he2010_A50_more" ;
global control4="$control3 University_exists ip_2011 logok2014 ef2010  educ2002" ;
global control4noOK="$control3 University_exists educ2002 ip_2011 ef2010" ;
global controlnopop4 = "ac disttopiter disttomoscow city2 logwage11 *_y2010 he2010_A20_24 he2010_A25_29 
	he2010_A30_34 he2010_A35_39 he2010_A40_44 he2010_A45_49 he2010_A50_more University_exists educ2002 
	ip_2011 logok2014 ef2010" ;
#d cr
// List controls for elections from different years as control5-control7
local controlall=""
forval i=5/7 {
	local y=95+(`i'-5)*4
	local y=`y'-int(`y'/100)*100
	local t="0`y'"
	local t=regexr("`t'","09","9")
	global control`i'="$control4 yabloko_`t' communists_`t' statusquo_`t' ldpr_`t' turnout_`t'"
	global controlnopop`i'="$controlnopop4 yabloko_`t' communists_`t' statusquo_`t' ldpr_`t' turnout_`t'"
	global control`i'noOK="$control4noOK yabloko_`t' communists_`t' statusquo_`t' ldpr_`t' turnout_`t'"
	global controlres`i'="$controlres4 yabloko_`t' communists_`t' statusquo_`t' ldpr_`t' turnout_`t'"
	local controlall="`controlall' yabloko_`t' communists_`t' statusquo_`t' ldpr_`t' turnout_`t'"
}
global control8="$control4 `controlall'"
global threshold="5"
global err=" cluster(okato_reg)"
global regtype="xi: reg"
global ivregtype="xi: ivreg2"
global proc=""
global weights = "[aweight=logpop]"
global logprot="log"
global logoldprot="logoldprot"
global loglabprot="log_Robertson_Total"
global dumprot="dum"
global dumoldprot="dumoldprot"
global dumlabprot="dum_Robertson_Total"
cd "$path/Tables" // Set the directory for storing tables

****************************************************************************************************
** Table 1. Penetration in 2011. 1st stage for cohorts
****************************************************************************************************

local opt="replace"
global outtable="Table 1 FINAL.xls"
local oldprot=""
local dec=4
foreach control in "control0" "control1" "control2" "control3" "control4" "control5" "control6" "control7" {
	qui $regtype logvk $SPcohorts $`control' `oldprot', $err 
	test logspbsu2=logspbsu1=logspbsu3
	local p_value_cohorts=r(p)
	test logspbsu2=logspbsu3
	local p_value_cohorts_old=r(p)
	test logspbsu2=logspbsu1
	local p_value_cohorts_young=r(p)
	qui sum logvk
	local mean=r(mean)
	local sd=r(sd)
	#d ;
	outreg2 using "$outtable", bracket  drop(educ2002 pop* lA* he*  yabloko* communists* statusquo* ldpr* turnout* ) 
			`opt' label dec(`dec') noaster nocons addstat("mean", `mean', "sd", `sd', "p-value equality all cohorts", 
			`p_value_cohorts', "p-value equality with young cohort",  `p_value_cohorts_young', 
			"p-value equality with old cohort", `p_value_cohorts_old') ;
	#d cr
	local opt="append"
}

****************************************************************************************************
** Table 2. VK Penetration and Protest Participation in 2011
****************************************************************************************************

* IV results
local opt="replace"
global outtable="Table 2 FINAL.xls"
foreach depvar in  dumprot logprot  {
	foreach control in "control4" "control5" "control6" "control7" {
			qui $ivregtype `depvar' (logvk=logspbsu2) $SPcohortsnoDurov  $`control' `oldprot' , $err
			local FKP=e(widstat)
			qui weakivtest
			local F0=r(F_eff)
			qui sum `depvar'
			local mean=r(mean)
			local sd=r(sd)
			#d ;
			outreg2 using "$outtable", bracket keep(logvk logspbsu1 logspbsu3) noaster 
				addstat("K-P F-stat", `FKP',"Effective F-statistics",`F0') `opt' label dec(3) nocons 
				addtext("mean", `mean', "sd", `sd') ;
			#d cr
			local opt="append"
		}
}

*ssc install weakiv // If not installed
foreach yvar in "dumprot" "logprot" {
	foreach control in "control4" "control5" "control6" "control7" { 
		qui ivreg2 `yvar' (logvk=logspbsu2) logspbsu1 logspbsu3 $`control', cluster(okato_reg)
		qui weakiv, lm usegrid gridpoints(500) gridmin(-1) gridmax(9)
		display e(ar_cset)
	}
}

* OLS results
foreach depvar in  dumprot logprot  {
	foreach control in "control4" "control5" "control6" "control7" {
		qui $regtype `depvar' logvk $SPcohortsnoDurov $`control' `oldprot' , $err
		outreg2 using "$outtable", bracket keep(logvk logspbsu1 logspbsu3) `opt' label dec(3) nocons noaster
		local opt="append"
	}	
}	

****************************************************************************************************
** Table 3. VK Penetration and Voting Outcomes
****************************************************************************************************

* IV results
local opt="replace"
global outtable="Table 3 IV FINAL.xls"
foreach depvar in statusquo1_07 statusquo1_08 statusquo1_11 statusquo1_12 statusquo1_16 {
	foreach control in "" "communists_95 ldpr_95 statusquo_95 yabloko_95 turnout_95" ///
		"communists_99 statusquo_99 ldpr_99 yabloko_99 turnout_99"		///
		"communists_03 statusquo_03 ldpr_03 yabloko_03 turnout_03" {
			qui $ivregtype `depvar' (logvk=logspbsu2) $SPcohortsnoDurov  $control4 `control' [aweight=logpop], $err partial(  $control4 `control' )
			outreg2 using "$outtable", bracket drop(pop* lA* he* educ* ) `opt' label dec(3) nocons noaster 
		local opt="append"
		}	
}
foreach yvar in statusquo1_07 statusquo1_08 statusquo1_11 statusquo1_12 statusquo1_16 {
	foreach control in "control4" "control5" "control6" "control7" { 
		qui ivreg2 `yvar' (logvk=logspbsu2) logspbsu1 logspbsu3 $`control' [aweight=logpop], cluster(okato_reg)
		qui weakiv, lm usegrid gridpoints(500) gridmin(-1) gridmax(9)
		display e(ar_cset)
	}
}

* OLS results
local opt="replace"
global outtable="Table 3 OLS FINAL.xls"
foreach depvar in statusquo1_07 statusquo1_08 statusquo1_11 statusquo1_12 statusquo1_16 {
	foreach control in "control4" "control5" "control6" "control7" {
			qui $regtype `depvar' logvk  $SPcohortsnoDurov  $`control' `oldprot'  [aweight=logpop], $err
			outreg2 using "$outtable", bracket keep(logvk logspbsu1 logspbsu3) `opt' label dec(3) nocons noaster 
			local opt="append"
		}	
}

****************************************************************************************************
** Table 4. VK Penetration and Voting Outcomes
****************************************************************************************************

* Load survey data and define a couple of global macro
use "$path/socialmedia_data_survey.dta", clear
global weight="[aweight=Weight]"
global outtable="Table 4 FINAL.xls" 

* Support of Medvedev, Putin, and government
local opt="replace"
forvalues x=4/6 {
	xi  i.Q`x', noomit
	drop _IQ`x'_7
	forvalues y=1/6 {
		qui ivreg2 _IQ`x'_`y' (logvk=logspbsu2) $SPcohortsnoDurov $control4 $weight , $err 
		qui weakivtest
		local F0=r(F_eff)
		outreg2 using "$outtable", bracket keep(logvk logspbsu1 logspbsu3) addstat("Effective F-statistics",`F0') `opt' label dec(3) nocons noaster
		local opt="append"
	}	
}	

* Intention to vote
local opt="append"
local x="10"
xi  i.Q`x', noomit
foreach var of varlist _IQ10_4 _IQ10_1 _IQ10_2 _IQ10_3 _IQ10_5 _IQ10_7 {
	qui ivreg2 `var' (logvk=logspbsu2) $SPcohortsnoDurov $control4 $weight , $err 
	qui weakivtest
	local F0=r(F_eff)
	outreg2 using "$outtable", bracket keep(logvk logspbsu1 logspbsu3) addstat("Effective F-statistics",`F0') `opt' label dec(3) nocons noaster
	local opt="append"
}	

* Ready to participate in protest
local opt="append"
local x="41"
xi  i.Q`x', noomit
forvalues y=1/3 {
	qui ivreg2 _IQ`x'_`y' (logvk=logspbsu2) $SPcohortsnoDurov $control4 $weight , $err 
	qui weakivtest
	local F0=r(F_eff)
	outreg2 using "$outtable", bracket keep(logvk logspbsu1 logspbsu3) addstat("Effective F-statistics",`F0') `opt' label dec(3) nocons noaster
	local opt="append"
}	
