clear all
set more off
global path="C:/Downloads/" // Set the path to the folder with replication files

****************************************************************************************************
** Load the city-level data and define global macro
****************************************************************************************************

use "$path/socialmedia_data_main.dta", clear
global SPcohorts="logspbsu2 logspbsu1 logspbsu3"
global SPcohortsnoDurov="logspbsu1 logspbsu3"
#d ;
global control_pop="pop pop_2 pop_3 pop_4 pop_5 " ;
global control0="" ;
global control1="$control_pop" ;
global control2="$control_pop  ac " ;
global control3="$control2 disttopiter disttomoscow city2 logwage11 lA20_24_y2010 lA25_29_y2010 
		lA30_34_y2010 lA35_39_y2010  lA40_44_y2010 lA45_49_y2010 lA50_more_y2010 he2010_A20_24 
		he2010_A25_29 he2010_A30_34 he2010_A35_39 he2010_A40_44 he2010_A45_49 he2010_A50_more" ;
global control4="$control3 University_exists ip_2011 logok2014 ef2010  educ2002" ;
global control4noOK="$control3 University_exists educ2002 ip_2011 ef2010" ;
global controlnopop4 = "ac disttopiter disttomoscow city2 logwage11 *_y2010 he2010_A20_24 he2010_A25_29 
	he2010_A30_34 he2010_A35_39 he2010_A40_44 he2010_A45_49 he2010_A50_more University_exists educ2002 
	ip_2011 logok2014 ef2010" ;
#d cr
// List controls for elections from different years as control5-control7
local controlall=""
forval i=5/7 {
	local y=95+(`i'-5)*4
	local y=`y'-int(`y'/100)*100
	local t="0`y'"
	local t=regexr("`t'","09","9")
	global control`i'="$control4 yabloko_`t' communists_`t' statusquo_`t' ldpr_`t' turnout_`t'"
	global controlnopop`i'="$controlnopop4 yabloko_`t' communists_`t' statusquo_`t' ldpr_`t' turnout_`t'"
	global control`i'noOK="$control4noOK yabloko_`t' communists_`t' statusquo_`t' ldpr_`t' turnout_`t'"
	global controlres`i'="$controlres4 yabloko_`t' communists_`t' statusquo_`t' ldpr_`t' turnout_`t'"
	local controlall="`controlall' yabloko_`t' communists_`t' statusquo_`t' ldpr_`t' turnout_`t'"
}
global control8="$control4 `controlall'"
global threshold="5"
global err=" cluster(okato_reg)"
global regtype="xi: reg"
global ivregtype="xi: ivreg2"
global proc=""
global weights = "[aweight=logpop]"
global logprot="log"
global logoldprot="logoldprot"
global loglabprot="log_Robertson_Total"
global dumprot="dum"
global dumoldprot="dumoldprot"
global dumlabprot="dum_Robertson_Total"
cd "$path/Tables" // Set the directory for storing tables

****************************************************************************************************
** Table TA1. Student Cohorts and Protest Participation in 2011. Reduced Form Estimation.
****************************************************************************************************

local opt="replace"
global outtable="Table TA1 FINAL.xls"
foreach depvar in "dumprot" "logprot" {
	foreach control in "control4" "control5" "control6" "control7" {
		qui $regtype `depvar' $SPcohorts $`control', $err
		qui test logspbsu2=logspbsu1=logspbsu3
		local p_value_cohorts=r(p)
		qui test logspbsu2=logspbsu3
		local p_value_cohorts_old=r(p)
		qui test logspbsu2=logspbsu1
		local p_value_cohorts_young=r(p)			
		qui sum `depvar' 
		local mean=r(mean)
		local sd=r(sd)
		#d ;
		outreg2 using "$outtable", bracket drop(pop* lA* he*  yabloko* communists* statusquo* ldpr* turnout* )
			`opt' label dec(3) nocons noaster addstat("mean", `mean', "sd", `sd', "p-value equality all cohorts", 
			`p_value_cohorts',"p-value equality with young cohort", `p_value_cohorts_young', 
			"p-value equality with old cohort", `p_value_cohorts_old') ;
		#d cr
		local opt="append"
	}	
}

****************************************************************************************************
** Table TA2. VK Penetration and Pre-VK Protests
****************************************************************************************************

* Panel A. Incidence
local opt="replace"
global outtable="Table TA2 FINAL.xls"
foreach depvar in dumoldprot dumoldprot_dem dummonprot dum_Robertson_Total {
	local oldprot=""
	foreach control in "control4" "control5" "control6" "control7" {
			if regexm("`depvar'","dumprot") {
				local oldprot=""
			}	
			qui cmp (dumprot=logvk $SPcohortsnoDurov $`control' ) (`depvar' =logvk $SPcohortsnoDurov $`control' ) (logvk=logspbsu2 $SPcohortsnoDurov $`control' ), indicators(1 1 1) $err
			qui test [dumprot]:logvk=[`depvar' ]:logvk
			local pvalue=r(p)
			qui $ivregtype `depvar' (logvk=logspbsu2) $SPcohortsnoDurov  $`control' `oldprot' , $err
			local FKP=e(widstat)
			qui weakivtest
			local F0=r(F_eff)
			#d ;
			outreg2 using "$outtable", bracket keep(logvk) label dec(3) nocons noaster
				addstat("K-P F-stat", `FKP', "Effective F-statistics",`F0',"Equality of coef", `pvalue') `opt' ;
			#d cr
			local opt="append"
		}	
}

* Panel B. Number of Participants
foreach depvar in logoldprot logoldprot_dem logmonprot log_Robertson_Total {
	local oldprot=""
	foreach control in "control4" "control5" "control6" "control7" {
			if regexm("`depvar'","dumprot") {
				local oldprot=""
			}	
			qui cmp (logprot=logvk $SPcohortsnoDurov $`control' ) (`depvar' =logvk $SPcohortsnoDurov $`control' ) (logvk=logspbsu2 $SPcohortsnoDurov $`control' ), indicators(1 1 1) cluster(okato_reg)
			qui test [logprot]:logvk=[`depvar' ]:logvk
			local pvalue=r(p)
			qui $ivregtype `depvar' (logvk=logspbsu2) $SPcohortsnoDurov  $`control' `oldprot' , $err
			local FKP=e(widstat)
			qui weakivtest
			local F0=r(F_eff)
			#d ;
			outreg2 using "$outtable", bracket keep(logvk) label dec(3) nocons noaster
				addstat("K-P F-stat", `FKP', "Effective F-statistics",`F0',"Equality of coef", `pvalue') `opt' ;
			#d cr
			local opt="append"
		}	
}

****************************************************************************************************
** Table TA3. VK Penetration and Pre-VK Voting Results
****************************************************************************************************

local opt="replace"
global outtable="Table TA3 FINAL.xls"

* Panel A. Parliamentary elections
foreach t in 95 99 03  {
	foreach var in statusquo_`t' yabloko_`t' communists_`t' ldpr_`t' against_`t'  turnout_`t'  {
		qui $ivregtype `var' (logvk=logspbsu2) $SPcohortsnoDurov  $control4 `cohorts' $weights , $err
		local FKP=e(widstat)
		qui weakivtest
		local F0=r(F_eff)
		outreg2 using "$outtable", bracket keep(logvk) addstat ("K-P F-stat", `FKP', "Effective F-statistics", `F0') `opt' label dec(3) nocons noaster 
		local opt="append"
	}	
}

* Panel B. Presidential elections
foreach var in Votes_1_1996 Votes_4_1996 Votes_2_1996 Votes_3_1996 Votes_11_1996 turnout1996 Votes_1_1996_2nd Votes_2_1996_2nd Votes_11_1996_2nd turnout1996_2nd { 
		qui $ivregtype `var' (logvk=logspbsu2) $SPcohortsnoDurov $control4 $weights , $err
		local FKP=e(widstat)
		qui weakivtest
		local F0=r(F_eff)
		outreg2 using "$outtable", bracket keep(logvk) addstat ("K-P F-stat", `FKP', "Effective F-statistics", `F0') `opt' label dec(3) nocons noaster 
}		
foreach var in statusquo1_00 yavlinsk1_00 zyuganov1_00 tuleev1_00 against1_00 turnout1_00 zhirinov1_00 {
		qui $ivregtype `var' (logvk=logspbsu2) $SPcohortsnoDurov $control4 $weights , $err
		local FKP=e(widstat)
		qui weakivtest
		local F0=r(F_eff)
		outreg2 using "$outtable", bracket keep(logvk) addstat ("K-P F-stat", `FKP', "Effective F-statistics", `F0') `opt' label dec(3) nocons noaster 
}			
foreach var in statusquo1_04 hakamada1_04 haritonov1_04 glaziev1_04 turnout1_04 {
		qui $ivregtype `var' (logvk=logspbsu2) $SPcohortsnoDurov $control4 $weights , $err
		local FKP=e(widstat)
		qui weakivtest
		local F0=r(F_eff)
		outreg2 using "$outtable", bracket keep(logvk) addstat ("K-P F-stat", `FKP', "Effective F-statistics", `F0') `opt' label dec(3) nocons noaster 
}			

****************************************************************************************************
** Table TA4. Fractionalization of Networks and Protest Participation
****************************************************************************************************

local opt="replace"
global outtable="Table TA4 FINAL.xls"
foreach depvar in logprot dumprot {
	foreach cond in  "" "if pop>100"  {
		foreach control in "control4" "control5" "control6" "control7" {
			qui $regtype  `depvar' fract11b lognet11b $`control' `cond' , $err
			qui sum `depvar' if e(sample)
			local mean=r(mean)
			local sd=r(sd)
			outreg2 using "$outtable", bracket keep(fract11b lognet11b) `opt' label dec(3) nocons addstat("mean", `mean', "sd", `sd') noaster
			local opt="append"
		}	
	}
}	